@@ -4,6 +4,9 @@ import webbrowser as web
 import requests
 import smtplib
 from email.mime.text import MIMEText
+import mahjong
+from mahjong.tile import TilesConverter
+from mahjong.shanten import Shanten
 
 def help():
     print("example")
@@ -16,6 +19,7 @@ def help():
     print(" torancell.weather()")
     print(" torancell.mail(your mailaddress)")
     print(" list = torancell.handgen()")
+    print(" torancell.shantenquiz()")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -445,33 +449,47 @@ def mail(adrs):
     server.send_message(msg)
     server.quit()
 
+
+mans = []
+sous = []
+pins = []
+jihai = []
 def ttt(i):
     return i//4+1
 def intmahjong(i):
     if i<=9:
+        mans.append(str(i))
         return str(i)+"m"
     elif i<=18:
+        sous.append(str(i-9))
         return str(i-9)+"s"
     elif i<=27:
+        pins.append(str(i-18))
         return str(i-18)+"p"
     elif i==28:
+        jihai.append(str(i-27))
         return "ton"
     elif i==29:
+        jihai.append(str(i-27))
         return "nan"
     elif i==30:
+        jihai.append(str(i-27))
         return "sya"
     elif i==31:
+        jihai.append(str(i-27))
         return "pei"
     elif i==32:
+        jihai.append(str(i-27))
         return "haku"
     elif i==33:
+        jihai.append(str(i-27))
         return "hatu"
     elif i==34:
+        jihai.append(str(i-27))
         return "tyun"
-def handgen():
+def handgen(t=13):
     i = list(range(1,136))
     rm.shuffle(i)
-    t = 13
     l = list()
     while t!=0:
         l.append(i.pop())
@@ -481,5 +499,17 @@ def handgen():
     hand = list(map(intmahjong,inthand))
     return hand
 
-
-    
\ No newline at end of file
+def shantenquiz():
+    print(handgen())
+    jmans=''.join(mans)
+    jsous=''.join(sous)
+    jpins=''.join(pins)
+    jjihai=''.join(jihai)
+    shanten = Shanten()
+    tiles = TilesConverter.string_to_34_array(man=jmans,sou=jsous,pin=jpins,honors=jjihai)
+    result = shanten.calculate_shanten(tiles)
+    chanten = int(input("How many shanten? : "))
+    if result == chanten:
+        print(True)
+    else:
+        print("False, correct answer is "+str(result))
\ No newline at end of file
